# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dgt_sdk/protobuf/consensus.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dgt_sdk/protobuf/consensus.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n dgt_sdk/protobuf/consensus.proto\"|\n\x1a\x43onsensusPeerMessageHeader\x12\x11\n\tsigner_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63ontent_sha512\x18\x02 \x01(\t\x12\x14\n\x0cmessage_type\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"T\n\x17\x43onsensusPeerMessageNew\x12\x0e\n\x06header\x18\x01 \x01(\x0c\x12\x18\n\x10header_signature\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"\\\n\x14\x43onsensusPeerMessage\x12\x14\n\x0cmessage_type\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\x7f\n\x0e\x43onsensusBlock\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\x12\x13\n\x0bprevious_id\x18\x02 \x01(\x0c\x12\x11\n\tsigner_id\x18\x03 \x01(\x0c\x12\x11\n\tblock_num\x18\x04 \x01(\x04\x12\x0f\n\x07payload\x18\x05 \x01(\x0c\x12\x0f\n\x07summary\x18\x06 \x01(\x0c\"$\n\x11\x43onsensusPeerInfo\x12\x0f\n\x07peer_id\x18\x01 \x01(\x0c\"4\n\x16\x43onsensusSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"4\n\x13\x43onsensusStateEntry\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"9\n\x18\x43onsensusRegisterRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xbe\x02\n\x19\x43onsensusRegisterResponse\x12\x31\n\x06status\x18\x01 \x01(\x0e\x32!.ConsensusRegisterResponse.Status\x12#\n\nchain_head\x18\x02 \x01(\x0b\x32\x0f.ConsensusBlock\x12!\n\x05peers\x18\x03 \x03(\x0b\x32\x12.ConsensusPeerInfo\x12+\n\x0flocal_peer_info\x18\x04 \x01(\x0b\x32\x12.ConsensusPeerInfo\x12\x14\n\x0cpeering_mode\x18\x05 \x01(\t\"c\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x0c\n\x08RECOVERY\x10\x05\"\xd7\x03\n\x1c\x43onsensusNotifyPeerConnected\x12%\n\tpeer_info\x18\x01 \x01(\x0b\x32\x12.ConsensusPeerInfo\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.ConsensusNotifyPeerConnected.Status\x12\x31\n\x04mode\x18\x03 \x01(\x0e\x32#.ConsensusNotifyPeerConnected.Modes\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\"\xc6\x01\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\r\n\tNOT_READY\x10\x01\x12\x10\n\x0cSTATUS_UNSET\x10\x02\x12\x0f\n\x0bROLE_CHANGE\x10\x03\x12\x12\n\x0e\x41RBITER_CHANGE\x10\x04\x12\x0f\n\x0b\x41\x44\x44_CLUSTER\x10\x05\x12\x0f\n\x0b\x44\x45L_CLUSTER\x10\x06\x12\x0c\n\x08\x41\x44\x44_PEER\x10\x07\x12\x0c\n\x08\x44\x45L_PEER\x10\x08\x12\x10\n\x0cPARAM_UPDATE\x10\t\x12\x10\n\x0cJOIN_CLUSTER\x10\n\x12\x0c\n\x08SET_NEST\x10\x0b\"B\n\x05Modes\x12\n\n\x06NORMAL\x10\x00\x12\r\n\tMALICIOUS\x10\x01\x12\x0e\n\nMALICIOUS1\x10\x02\x12\x0e\n\nMALICIOUS2\x10\x03\"2\n\x1f\x43onsensusNotifyPeerDisconnected\x12\x0f\n\x07peer_id\x18\x01 \x01(\x0c\"W\n\x1a\x43onsensusNotifyPeerMessage\x12&\n\x07message\x18\x01 \x01(\x0b\x32\x15.ConsensusPeerMessage\x12\x11\n\tsender_id\x18\x02 \x01(\x0c\"]\n\x1d\x43onsensusNotifyPeerMessageNew\x12)\n\x07message\x18\x01 \x01(\x0b\x32\x18.ConsensusPeerMessageNew\x12\x11\n\tsender_id\x18\x02 \x01(\x0c\"9\n\x17\x43onsensusNotifyBlockNew\x12\x1e\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x0f.ConsensusBlock\"-\n\x19\x43onsensusNotifyBlockValid\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\"/\n\x1b\x43onsensusNotifyBlockInvalid\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\".\n\x1a\x43onsensusNotifyBlockCommit\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\"\x14\n\x12\x43onsensusNotifyAck\":\n\x16\x43onsensusSendToRequest\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x0f\n\x07peer_id\x18\x02 \x01(\x0c\"\xb3\x01\n\x17\x43onsensusSendToResponse\x12/\n\x06status\x18\x01 \x01(\x0e\x32\x1f.ConsensusSendToResponse.Status\"g\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x10\n\x0cUNKNOWN_PEER\x10\x05\",\n\x19\x43onsensusBroadcastRequest\x12\x0f\n\x07message\x18\x01 \x01(\x0c\"3\n ConsensusBroadcastClusterRequest\x12\x0f\n\x07message\x18\x01 \x01(\x0c\"3\n ConsensusBroadcastArbiterRequest\x12\x0f\n\x07message\x18\x01 \x01(\x0c\"\xa7\x01\n\x1a\x43onsensusBroadcastResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ConsensusBroadcastResponse.Status\"U\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\"\xb5\x01\n!ConsensusBroadcastArbiterResponse\x12\x39\n\x06status\x18\x01 \x01(\x0e\x32).ConsensusBroadcastArbiterResponse.Status\"U\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\"\xb5\x01\n!ConsensusBroadcastClusterResponse\x12\x39\n\x06status\x18\x01 \x01(\x0e\x32).ConsensusBroadcastClusterResponse.Status\"U\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\"K\n\x1f\x43onsensusInitializeBlockRequest\x12\x13\n\x0bprevious_id\x18\x01 \x01(\x0c\x12\x13\n\x0bnest_colour\x18\x02 \x01(\t\"\xd9\x01\n ConsensusInitializeBlockResponse\x12\x38\n\x06status\x18\x01 \x01(\x0e\x32(.ConsensusInitializeBlockResponse.Status\"{\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rINVALID_STATE\x10\x05\x12\x11\n\rUNKNOWN_BLOCK\x10\x06\" \n\x1e\x43onsensusSummarizeBlockRequest\"\xfc\x01\n\x1f\x43onsensusSummarizeBlockResponse\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.ConsensusSummarizeBlockResponse.Status\x12\x0f\n\x07summary\x18\x02 \x01(\x0c\x12\x10\n\x08\x62lock_id\x18\x03 \x01(\x0c\"}\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rINVALID_STATE\x10\x05\x12\x13\n\x0f\x42LOCK_NOT_READY\x10\x06\"?\n\x1d\x43onsensusFinalizeBlockRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x10\n\x08\x62lock_id\x18\x02 \x01(\x0c\"\xe9\x01\n\x1e\x43onsensusFinalizeBlockResponse\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.ConsensusFinalizeBlockResponse.Status\x12\x10\n\x08\x62lock_id\x18\x02 \x01(\x0c\"}\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rINVALID_STATE\x10\x05\x12\x13\n\x0f\x42LOCK_NOT_READY\x10\x06\"0\n\x1b\x43onsensusCancelBlockRequest\x12\x11\n\tbranch_id\x18\x01 \x01(\x0c\"\xbe\x01\n\x1c\x43onsensusCancelBlockResponse\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.ConsensusCancelBlockResponse.Status\"h\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rINVALID_STATE\x10\x05\"0\n\x1b\x43onsensusCheckBlocksRequest\x12\x11\n\tblock_ids\x18\x01 \x03(\x0c\"\xbe\x01\n\x1c\x43onsensusCheckBlocksResponse\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.ConsensusCheckBlocksResponse.Status\"h\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\"=\n\x1b\x43onsensusCommitBlockRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\x12\x0c\n\x04seal\x18\x02 \x01(\x0c\"\xbe\x01\n\x1c\x43onsensusCommitBlockResponse\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.ConsensusCommitBlockResponse.Status\"h\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\"/\n\x1b\x43onsensusIgnoreBlockRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\"\xbe\x01\n\x1c\x43onsensusIgnoreBlockResponse\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.ConsensusIgnoreBlockResponse.Status\"h\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\"-\n\x19\x43onsensusFailBlockRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\"\xba\x01\n\x1a\x43onsensusFailBlockResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ConsensusFailBlockResponse.Status\"h\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\".\n\x19\x43onsensusBlocksGetRequest\x12\x11\n\tblock_ids\x18\x01 \x03(\x0c\"\xf8\x01\n\x1a\x43onsensusBlocksGetResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".ConsensusBlocksGetResponse.Status\x12\x1f\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x0f.ConsensusBlock\"\x84\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\x12\x1a\n\x16\x42LOCK_IS_PROCESSED_NOW\x10\x06\"X\n\x1c\x43onsensusChainHeadGetRequest\x12\x11\n\tparent_id\x18\x01 \x01(\x0c\x12\x15\n\rnew_parent_id\x18\x02 \x01(\x0c\x12\x0e\n\x06is_new\x18\x03 \x01(\x08\"\x92\x02\n\x1d\x43onsensusChainHeadGetResponse\x12\x35\n\x06status\x18\x01 \x01(\x0e\x32%.ConsensusChainHeadGetResponse.Status\x12\x1e\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x0f.ConsensusBlock\"\x99\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rNO_CHAIN_HEAD\x10\x05\x12\x13\n\x0fTOO_MANY_BRANCH\x10\x06\x12\x1a\n\x16\x42LOCK_IS_PROCESSED_NOW\x10\x07\"=\n\x1b\x43onsensusSettingsGetRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\x12\x0c\n\x04keys\x18\x02 \x03(\t\"\x85\x02\n\x1c\x43onsensusSettingsGetResponse\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.ConsensusSettingsGetResponse.Status\x12(\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x17.ConsensusSettingsEntry\"\x84\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\x12\x1a\n\x16\x42LOCK_IS_PROCESSED_NOW\x10\x06\"?\n\x18\x43onsensusStateGetRequest\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\x0c\x12\x11\n\taddresses\x18\x02 \x03(\t\"\xfc\x01\n\x19\x43onsensusStateGetResponse\x12\x31\n\x06status\x18\x01 \x01(\x0e\x32!.ConsensusStateGetResponse.Status\x12%\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x14.ConsensusStateEntry\"\x84\x01\n\x06Status\x12\x10\n\x0cSTATUS_UNSET\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x02\x12\x11\n\rSERVICE_ERROR\x10\x03\x12\r\n\tNOT_READY\x10\x04\x12\x11\n\rUNKNOWN_BLOCK\x10\x05\x12\x1a\n\x16\x42LOCK_IS_PROCESSED_NOW\x10\x06\x62\x06proto3')
)



_CONSENSUSREGISTERRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusRegisterResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECOVERY', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=896,
  serialized_end=995,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSREGISTERRESPONSE_STATUS)

_CONSENSUSNOTIFYPEERCONNECTED_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusNotifyPeerConnected.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROLE_CHANGE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARBITER_CHANGE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD_CLUSTER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEL_CLUSTER', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD_PEER', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEL_PEER', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARAM_UPDATE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JOIN_CLUSTER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SET_NEST', index=11, number=11,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1203,
  serialized_end=1401,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSNOTIFYPEERCONNECTED_STATUS)

_CONSENSUSNOTIFYPEERCONNECTED_MODES = _descriptor.EnumDescriptor(
  name='Modes',
  full_name='ConsensusNotifyPeerConnected.Modes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS1', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALICIOUS2', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1403,
  serialized_end=1469,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSNOTIFYPEERCONNECTED_MODES)

_CONSENSUSSENDTORESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusSendToResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_PEER', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2069,
  serialized_end=2172,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSSENDTORESPONSE_STATUS)

_CONSENSUSBROADCASTRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusBroadcastResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=896,
  serialized_end=981,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSBROADCASTRESPONSE_STATUS)

_CONSENSUSBROADCASTARBITERRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusBroadcastArbiterResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=896,
  serialized_end=981,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSBROADCASTARBITERRESPONSE_STATUS)

_CONSENSUSBROADCASTCLUSTERRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusBroadcastClusterResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=896,
  serialized_end=981,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSBROADCASTCLUSTERRESPONSE_STATUS)

_CONSENSUSINITIALIZEBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusInitializeBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3036,
  serialized_end=3159,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSINITIALIZEBLOCKRESPONSE_STATUS)

_CONSENSUSSUMMARIZEBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusSummarizeBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_NOT_READY', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3323,
  serialized_end=3448,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSSUMMARIZEBLOCKRESPONSE_STATUS)

_CONSENSUSFINALIZEBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusFinalizeBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_NOT_READY', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3323,
  serialized_end=3448,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSFINALIZEBLOCKRESPONSE_STATUS)

_CONSENSUSCANCELBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusCancelBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_STATE', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3036,
  serialized_end=3140,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSCANCELBLOCKRESPONSE_STATUS)

_CONSENSUSCHECKBLOCKSRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusCheckBlocksResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4131,
  serialized_end=4235,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSCHECKBLOCKSRESPONSE_STATUS)

_CONSENSUSCOMMITBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusCommitBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4131,
  serialized_end=4235,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSCOMMITBLOCKRESPONSE_STATUS)

_CONSENSUSIGNOREBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusIgnoreBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4131,
  serialized_end=4235,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSIGNOREBLOCKRESPONSE_STATUS)

_CONSENSUSFAILBLOCKRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusFailBlockResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4131,
  serialized_end=4235,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSFAILBLOCKRESPONSE_STATUS)

_CONSENSUSBLOCKSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusBlocksGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_IS_PROCESSED_NOW', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5136,
  serialized_end=5268,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSBLOCKSGETRESPONSE_STATUS)

_CONSENSUSCHAINHEADGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusChainHeadGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_CHAIN_HEAD', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_BRANCH', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_IS_PROCESSED_NOW', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5482,
  serialized_end=5635,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSCHAINHEADGETRESPONSE_STATUS)

_CONSENSUSSETTINGSGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusSettingsGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_IS_PROCESSED_NOW', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5136,
  serialized_end=5268,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSSETTINGSGETRESPONSE_STATUS)

_CONSENSUSSTATEGETRESPONSE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='ConsensusStateGetResponse.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_READY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_BLOCK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLOCK_IS_PROCESSED_NOW', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5136,
  serialized_end=5268,
)
_sym_db.RegisterEnumDescriptor(_CONSENSUSSTATEGETRESPONSE_STATUS)


_CONSENSUSPEERMESSAGEHEADER = _descriptor.Descriptor(
  name='ConsensusPeerMessageHeader',
  full_name='ConsensusPeerMessageHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signer_id', full_name='ConsensusPeerMessageHeader.signer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_sha512', full_name='ConsensusPeerMessageHeader.content_sha512', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='ConsensusPeerMessageHeader.message_type', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ConsensusPeerMessageHeader.name', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ConsensusPeerMessageHeader.version', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=160,
)


_CONSENSUSPEERMESSAGENEW = _descriptor.Descriptor(
  name='ConsensusPeerMessageNew',
  full_name='ConsensusPeerMessageNew',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='ConsensusPeerMessageNew.header', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_signature', full_name='ConsensusPeerMessageNew.header_signature', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ConsensusPeerMessageNew.content', index=2,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=246,
)


_CONSENSUSPEERMESSAGE = _descriptor.Descriptor(
  name='ConsensusPeerMessage',
  full_name='ConsensusPeerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_type', full_name='ConsensusPeerMessage.message_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ConsensusPeerMessage.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='ConsensusPeerMessage.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ConsensusPeerMessage.version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=340,
)


_CONSENSUSBLOCK = _descriptor.Descriptor(
  name='ConsensusBlock',
  full_name='ConsensusBlock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusBlock.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_id', full_name='ConsensusBlock.previous_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_id', full_name='ConsensusBlock.signer_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_num', full_name='ConsensusBlock.block_num', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payload', full_name='ConsensusBlock.payload', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='ConsensusBlock.summary', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=469,
)


_CONSENSUSPEERINFO = _descriptor.Descriptor(
  name='ConsensusPeerInfo',
  full_name='ConsensusPeerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='ConsensusPeerInfo.peer_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=507,
)


_CONSENSUSSETTINGSENTRY = _descriptor.Descriptor(
  name='ConsensusSettingsEntry',
  full_name='ConsensusSettingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ConsensusSettingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='ConsensusSettingsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=509,
  serialized_end=561,
)


_CONSENSUSSTATEENTRY = _descriptor.Descriptor(
  name='ConsensusStateEntry',
  full_name='ConsensusStateEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='ConsensusStateEntry.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='ConsensusStateEntry.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=615,
)


_CONSENSUSREGISTERREQUEST = _descriptor.Descriptor(
  name='ConsensusRegisterRequest',
  full_name='ConsensusRegisterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ConsensusRegisterRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='ConsensusRegisterRequest.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=674,
)


_CONSENSUSREGISTERRESPONSE = _descriptor.Descriptor(
  name='ConsensusRegisterResponse',
  full_name='ConsensusRegisterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusRegisterResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_head', full_name='ConsensusRegisterResponse.chain_head', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers', full_name='ConsensusRegisterResponse.peers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_peer_info', full_name='ConsensusRegisterResponse.local_peer_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peering_mode', full_name='ConsensusRegisterResponse.peering_mode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSREGISTERRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=677,
  serialized_end=995,
)


_CONSENSUSNOTIFYPEERCONNECTED = _descriptor.Descriptor(
  name='ConsensusNotifyPeerConnected',
  full_name='ConsensusNotifyPeerConnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_info', full_name='ConsensusNotifyPeerConnected.peer_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusNotifyPeerConnected.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='ConsensusNotifyPeerConnected.mode', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='ConsensusNotifyPeerConnected.info', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='ConsensusNotifyPeerConnected.data', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSNOTIFYPEERCONNECTED_STATUS,
    _CONSENSUSNOTIFYPEERCONNECTED_MODES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=998,
  serialized_end=1469,
)


_CONSENSUSNOTIFYPEERDISCONNECTED = _descriptor.Descriptor(
  name='ConsensusNotifyPeerDisconnected',
  full_name='ConsensusNotifyPeerDisconnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='ConsensusNotifyPeerDisconnected.peer_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1471,
  serialized_end=1521,
)


_CONSENSUSNOTIFYPEERMESSAGE = _descriptor.Descriptor(
  name='ConsensusNotifyPeerMessage',
  full_name='ConsensusNotifyPeerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ConsensusNotifyPeerMessage.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='ConsensusNotifyPeerMessage.sender_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1610,
)


_CONSENSUSNOTIFYPEERMESSAGENEW = _descriptor.Descriptor(
  name='ConsensusNotifyPeerMessageNew',
  full_name='ConsensusNotifyPeerMessageNew',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ConsensusNotifyPeerMessageNew.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_id', full_name='ConsensusNotifyPeerMessageNew.sender_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1705,
)


_CONSENSUSNOTIFYBLOCKNEW = _descriptor.Descriptor(
  name='ConsensusNotifyBlockNew',
  full_name='ConsensusNotifyBlockNew',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='ConsensusNotifyBlockNew.block', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1707,
  serialized_end=1764,
)


_CONSENSUSNOTIFYBLOCKVALID = _descriptor.Descriptor(
  name='ConsensusNotifyBlockValid',
  full_name='ConsensusNotifyBlockValid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusNotifyBlockValid.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1766,
  serialized_end=1811,
)


_CONSENSUSNOTIFYBLOCKINVALID = _descriptor.Descriptor(
  name='ConsensusNotifyBlockInvalid',
  full_name='ConsensusNotifyBlockInvalid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusNotifyBlockInvalid.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1813,
  serialized_end=1860,
)


_CONSENSUSNOTIFYBLOCKCOMMIT = _descriptor.Descriptor(
  name='ConsensusNotifyBlockCommit',
  full_name='ConsensusNotifyBlockCommit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusNotifyBlockCommit.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1862,
  serialized_end=1908,
)


_CONSENSUSNOTIFYACK = _descriptor.Descriptor(
  name='ConsensusNotifyAck',
  full_name='ConsensusNotifyAck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1910,
  serialized_end=1930,
)


_CONSENSUSSENDTOREQUEST = _descriptor.Descriptor(
  name='ConsensusSendToRequest',
  full_name='ConsensusSendToRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ConsensusSendToRequest.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peer_id', full_name='ConsensusSendToRequest.peer_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1932,
  serialized_end=1990,
)


_CONSENSUSSENDTORESPONSE = _descriptor.Descriptor(
  name='ConsensusSendToResponse',
  full_name='ConsensusSendToResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusSendToResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSSENDTORESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1993,
  serialized_end=2172,
)


_CONSENSUSBROADCASTREQUEST = _descriptor.Descriptor(
  name='ConsensusBroadcastRequest',
  full_name='ConsensusBroadcastRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ConsensusBroadcastRequest.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2174,
  serialized_end=2218,
)


_CONSENSUSBROADCASTCLUSTERREQUEST = _descriptor.Descriptor(
  name='ConsensusBroadcastClusterRequest',
  full_name='ConsensusBroadcastClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ConsensusBroadcastClusterRequest.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2271,
)


_CONSENSUSBROADCASTARBITERREQUEST = _descriptor.Descriptor(
  name='ConsensusBroadcastArbiterRequest',
  full_name='ConsensusBroadcastArbiterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='ConsensusBroadcastArbiterRequest.message', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2273,
  serialized_end=2324,
)


_CONSENSUSBROADCASTRESPONSE = _descriptor.Descriptor(
  name='ConsensusBroadcastResponse',
  full_name='ConsensusBroadcastResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusBroadcastResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSBROADCASTRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2327,
  serialized_end=2494,
)


_CONSENSUSBROADCASTARBITERRESPONSE = _descriptor.Descriptor(
  name='ConsensusBroadcastArbiterResponse',
  full_name='ConsensusBroadcastArbiterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusBroadcastArbiterResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSBROADCASTARBITERRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2497,
  serialized_end=2678,
)


_CONSENSUSBROADCASTCLUSTERRESPONSE = _descriptor.Descriptor(
  name='ConsensusBroadcastClusterResponse',
  full_name='ConsensusBroadcastClusterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusBroadcastClusterResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSBROADCASTCLUSTERRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2681,
  serialized_end=2862,
)


_CONSENSUSINITIALIZEBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusInitializeBlockRequest',
  full_name='ConsensusInitializeBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='previous_id', full_name='ConsensusInitializeBlockRequest.previous_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nest_colour', full_name='ConsensusInitializeBlockRequest.nest_colour', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2864,
  serialized_end=2939,
)


_CONSENSUSINITIALIZEBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusInitializeBlockResponse',
  full_name='ConsensusInitializeBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusInitializeBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSINITIALIZEBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2942,
  serialized_end=3159,
)


_CONSENSUSSUMMARIZEBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusSummarizeBlockRequest',
  full_name='ConsensusSummarizeBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3161,
  serialized_end=3193,
)


_CONSENSUSSUMMARIZEBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusSummarizeBlockResponse',
  full_name='ConsensusSummarizeBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusSummarizeBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='ConsensusSummarizeBlockResponse.summary', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusSummarizeBlockResponse.block_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSSUMMARIZEBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3196,
  serialized_end=3448,
)


_CONSENSUSFINALIZEBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusFinalizeBlockRequest',
  full_name='ConsensusFinalizeBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='ConsensusFinalizeBlockRequest.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusFinalizeBlockRequest.block_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3513,
)


_CONSENSUSFINALIZEBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusFinalizeBlockResponse',
  full_name='ConsensusFinalizeBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusFinalizeBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusFinalizeBlockResponse.block_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSFINALIZEBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3516,
  serialized_end=3749,
)


_CONSENSUSCANCELBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusCancelBlockRequest',
  full_name='ConsensusCancelBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch_id', full_name='ConsensusCancelBlockRequest.branch_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3751,
  serialized_end=3799,
)


_CONSENSUSCANCELBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusCancelBlockResponse',
  full_name='ConsensusCancelBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusCancelBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSCANCELBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3802,
  serialized_end=3992,
)


_CONSENSUSCHECKBLOCKSREQUEST = _descriptor.Descriptor(
  name='ConsensusCheckBlocksRequest',
  full_name='ConsensusCheckBlocksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_ids', full_name='ConsensusCheckBlocksRequest.block_ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3994,
  serialized_end=4042,
)


_CONSENSUSCHECKBLOCKSRESPONSE = _descriptor.Descriptor(
  name='ConsensusCheckBlocksResponse',
  full_name='ConsensusCheckBlocksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusCheckBlocksResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSCHECKBLOCKSRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4045,
  serialized_end=4235,
)


_CONSENSUSCOMMITBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusCommitBlockRequest',
  full_name='ConsensusCommitBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusCommitBlockRequest.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seal', full_name='ConsensusCommitBlockRequest.seal', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4237,
  serialized_end=4298,
)


_CONSENSUSCOMMITBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusCommitBlockResponse',
  full_name='ConsensusCommitBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusCommitBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSCOMMITBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4301,
  serialized_end=4491,
)


_CONSENSUSIGNOREBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusIgnoreBlockRequest',
  full_name='ConsensusIgnoreBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusIgnoreBlockRequest.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4493,
  serialized_end=4540,
)


_CONSENSUSIGNOREBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusIgnoreBlockResponse',
  full_name='ConsensusIgnoreBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusIgnoreBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSIGNOREBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4543,
  serialized_end=4733,
)


_CONSENSUSFAILBLOCKREQUEST = _descriptor.Descriptor(
  name='ConsensusFailBlockRequest',
  full_name='ConsensusFailBlockRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusFailBlockRequest.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4735,
  serialized_end=4780,
)


_CONSENSUSFAILBLOCKRESPONSE = _descriptor.Descriptor(
  name='ConsensusFailBlockResponse',
  full_name='ConsensusFailBlockResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusFailBlockResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSFAILBLOCKRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4783,
  serialized_end=4969,
)


_CONSENSUSBLOCKSGETREQUEST = _descriptor.Descriptor(
  name='ConsensusBlocksGetRequest',
  full_name='ConsensusBlocksGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_ids', full_name='ConsensusBlocksGetRequest.block_ids', index=0,
      number=1, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4971,
  serialized_end=5017,
)


_CONSENSUSBLOCKSGETRESPONSE = _descriptor.Descriptor(
  name='ConsensusBlocksGetResponse',
  full_name='ConsensusBlocksGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusBlocksGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blocks', full_name='ConsensusBlocksGetResponse.blocks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSBLOCKSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5020,
  serialized_end=5268,
)


_CONSENSUSCHAINHEADGETREQUEST = _descriptor.Descriptor(
  name='ConsensusChainHeadGetRequest',
  full_name='ConsensusChainHeadGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='ConsensusChainHeadGetRequest.parent_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_parent_id', full_name='ConsensusChainHeadGetRequest.new_parent_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_new', full_name='ConsensusChainHeadGetRequest.is_new', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5270,
  serialized_end=5358,
)


_CONSENSUSCHAINHEADGETRESPONSE = _descriptor.Descriptor(
  name='ConsensusChainHeadGetResponse',
  full_name='ConsensusChainHeadGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusChainHeadGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block', full_name='ConsensusChainHeadGetResponse.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSCHAINHEADGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5361,
  serialized_end=5635,
)


_CONSENSUSSETTINGSGETREQUEST = _descriptor.Descriptor(
  name='ConsensusSettingsGetRequest',
  full_name='ConsensusSettingsGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusSettingsGetRequest.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys', full_name='ConsensusSettingsGetRequest.keys', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5637,
  serialized_end=5698,
)


_CONSENSUSSETTINGSGETRESPONSE = _descriptor.Descriptor(
  name='ConsensusSettingsGetResponse',
  full_name='ConsensusSettingsGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusSettingsGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='ConsensusSettingsGetResponse.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSSETTINGSGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5701,
  serialized_end=5962,
)


_CONSENSUSSTATEGETREQUEST = _descriptor.Descriptor(
  name='ConsensusStateGetRequest',
  full_name='ConsensusStateGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_id', full_name='ConsensusStateGetRequest.block_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addresses', full_name='ConsensusStateGetRequest.addresses', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5964,
  serialized_end=6027,
)


_CONSENSUSSTATEGETRESPONSE = _descriptor.Descriptor(
  name='ConsensusStateGetResponse',
  full_name='ConsensusStateGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ConsensusStateGetResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='ConsensusStateGetResponse.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONSENSUSSTATEGETRESPONSE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6030,
  serialized_end=6282,
)

_CONSENSUSREGISTERRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSREGISTERRESPONSE_STATUS
_CONSENSUSREGISTERRESPONSE.fields_by_name['chain_head'].message_type = _CONSENSUSBLOCK
_CONSENSUSREGISTERRESPONSE.fields_by_name['peers'].message_type = _CONSENSUSPEERINFO
_CONSENSUSREGISTERRESPONSE.fields_by_name['local_peer_info'].message_type = _CONSENSUSPEERINFO
_CONSENSUSREGISTERRESPONSE_STATUS.containing_type = _CONSENSUSREGISTERRESPONSE
_CONSENSUSNOTIFYPEERCONNECTED.fields_by_name['peer_info'].message_type = _CONSENSUSPEERINFO
_CONSENSUSNOTIFYPEERCONNECTED.fields_by_name['status'].enum_type = _CONSENSUSNOTIFYPEERCONNECTED_STATUS
_CONSENSUSNOTIFYPEERCONNECTED.fields_by_name['mode'].enum_type = _CONSENSUSNOTIFYPEERCONNECTED_MODES
_CONSENSUSNOTIFYPEERCONNECTED_STATUS.containing_type = _CONSENSUSNOTIFYPEERCONNECTED
_CONSENSUSNOTIFYPEERCONNECTED_MODES.containing_type = _CONSENSUSNOTIFYPEERCONNECTED
_CONSENSUSNOTIFYPEERMESSAGE.fields_by_name['message'].message_type = _CONSENSUSPEERMESSAGE
_CONSENSUSNOTIFYPEERMESSAGENEW.fields_by_name['message'].message_type = _CONSENSUSPEERMESSAGENEW
_CONSENSUSNOTIFYBLOCKNEW.fields_by_name['block'].message_type = _CONSENSUSBLOCK
_CONSENSUSSENDTORESPONSE.fields_by_name['status'].enum_type = _CONSENSUSSENDTORESPONSE_STATUS
_CONSENSUSSENDTORESPONSE_STATUS.containing_type = _CONSENSUSSENDTORESPONSE
_CONSENSUSBROADCASTRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSBROADCASTRESPONSE_STATUS
_CONSENSUSBROADCASTRESPONSE_STATUS.containing_type = _CONSENSUSBROADCASTRESPONSE
_CONSENSUSBROADCASTARBITERRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSBROADCASTARBITERRESPONSE_STATUS
_CONSENSUSBROADCASTARBITERRESPONSE_STATUS.containing_type = _CONSENSUSBROADCASTARBITERRESPONSE
_CONSENSUSBROADCASTCLUSTERRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSBROADCASTCLUSTERRESPONSE_STATUS
_CONSENSUSBROADCASTCLUSTERRESPONSE_STATUS.containing_type = _CONSENSUSBROADCASTCLUSTERRESPONSE
_CONSENSUSINITIALIZEBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSINITIALIZEBLOCKRESPONSE_STATUS
_CONSENSUSINITIALIZEBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSINITIALIZEBLOCKRESPONSE
_CONSENSUSSUMMARIZEBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSSUMMARIZEBLOCKRESPONSE_STATUS
_CONSENSUSSUMMARIZEBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSSUMMARIZEBLOCKRESPONSE
_CONSENSUSFINALIZEBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSFINALIZEBLOCKRESPONSE_STATUS
_CONSENSUSFINALIZEBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSFINALIZEBLOCKRESPONSE
_CONSENSUSCANCELBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSCANCELBLOCKRESPONSE_STATUS
_CONSENSUSCANCELBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSCANCELBLOCKRESPONSE
_CONSENSUSCHECKBLOCKSRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSCHECKBLOCKSRESPONSE_STATUS
_CONSENSUSCHECKBLOCKSRESPONSE_STATUS.containing_type = _CONSENSUSCHECKBLOCKSRESPONSE
_CONSENSUSCOMMITBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSCOMMITBLOCKRESPONSE_STATUS
_CONSENSUSCOMMITBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSCOMMITBLOCKRESPONSE
_CONSENSUSIGNOREBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSIGNOREBLOCKRESPONSE_STATUS
_CONSENSUSIGNOREBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSIGNOREBLOCKRESPONSE
_CONSENSUSFAILBLOCKRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSFAILBLOCKRESPONSE_STATUS
_CONSENSUSFAILBLOCKRESPONSE_STATUS.containing_type = _CONSENSUSFAILBLOCKRESPONSE
_CONSENSUSBLOCKSGETRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSBLOCKSGETRESPONSE_STATUS
_CONSENSUSBLOCKSGETRESPONSE.fields_by_name['blocks'].message_type = _CONSENSUSBLOCK
_CONSENSUSBLOCKSGETRESPONSE_STATUS.containing_type = _CONSENSUSBLOCKSGETRESPONSE
_CONSENSUSCHAINHEADGETRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSCHAINHEADGETRESPONSE_STATUS
_CONSENSUSCHAINHEADGETRESPONSE.fields_by_name['block'].message_type = _CONSENSUSBLOCK
_CONSENSUSCHAINHEADGETRESPONSE_STATUS.containing_type = _CONSENSUSCHAINHEADGETRESPONSE
_CONSENSUSSETTINGSGETRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSSETTINGSGETRESPONSE_STATUS
_CONSENSUSSETTINGSGETRESPONSE.fields_by_name['entries'].message_type = _CONSENSUSSETTINGSENTRY
_CONSENSUSSETTINGSGETRESPONSE_STATUS.containing_type = _CONSENSUSSETTINGSGETRESPONSE
_CONSENSUSSTATEGETRESPONSE.fields_by_name['status'].enum_type = _CONSENSUSSTATEGETRESPONSE_STATUS
_CONSENSUSSTATEGETRESPONSE.fields_by_name['entries'].message_type = _CONSENSUSSTATEENTRY
_CONSENSUSSTATEGETRESPONSE_STATUS.containing_type = _CONSENSUSSTATEGETRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusPeerMessageHeader'] = _CONSENSUSPEERMESSAGEHEADER
DESCRIPTOR.message_types_by_name['ConsensusPeerMessageNew'] = _CONSENSUSPEERMESSAGENEW
DESCRIPTOR.message_types_by_name['ConsensusPeerMessage'] = _CONSENSUSPEERMESSAGE
DESCRIPTOR.message_types_by_name['ConsensusBlock'] = _CONSENSUSBLOCK
DESCRIPTOR.message_types_by_name['ConsensusPeerInfo'] = _CONSENSUSPEERINFO
DESCRIPTOR.message_types_by_name['ConsensusSettingsEntry'] = _CONSENSUSSETTINGSENTRY
DESCRIPTOR.message_types_by_name['ConsensusStateEntry'] = _CONSENSUSSTATEENTRY
DESCRIPTOR.message_types_by_name['ConsensusRegisterRequest'] = _CONSENSUSREGISTERREQUEST
DESCRIPTOR.message_types_by_name['ConsensusRegisterResponse'] = _CONSENSUSREGISTERRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusNotifyPeerConnected'] = _CONSENSUSNOTIFYPEERCONNECTED
DESCRIPTOR.message_types_by_name['ConsensusNotifyPeerDisconnected'] = _CONSENSUSNOTIFYPEERDISCONNECTED
DESCRIPTOR.message_types_by_name['ConsensusNotifyPeerMessage'] = _CONSENSUSNOTIFYPEERMESSAGE
DESCRIPTOR.message_types_by_name['ConsensusNotifyPeerMessageNew'] = _CONSENSUSNOTIFYPEERMESSAGENEW
DESCRIPTOR.message_types_by_name['ConsensusNotifyBlockNew'] = _CONSENSUSNOTIFYBLOCKNEW
DESCRIPTOR.message_types_by_name['ConsensusNotifyBlockValid'] = _CONSENSUSNOTIFYBLOCKVALID
DESCRIPTOR.message_types_by_name['ConsensusNotifyBlockInvalid'] = _CONSENSUSNOTIFYBLOCKINVALID
DESCRIPTOR.message_types_by_name['ConsensusNotifyBlockCommit'] = _CONSENSUSNOTIFYBLOCKCOMMIT
DESCRIPTOR.message_types_by_name['ConsensusNotifyAck'] = _CONSENSUSNOTIFYACK
DESCRIPTOR.message_types_by_name['ConsensusSendToRequest'] = _CONSENSUSSENDTOREQUEST
DESCRIPTOR.message_types_by_name['ConsensusSendToResponse'] = _CONSENSUSSENDTORESPONSE
DESCRIPTOR.message_types_by_name['ConsensusBroadcastRequest'] = _CONSENSUSBROADCASTREQUEST
DESCRIPTOR.message_types_by_name['ConsensusBroadcastClusterRequest'] = _CONSENSUSBROADCASTCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ConsensusBroadcastArbiterRequest'] = _CONSENSUSBROADCASTARBITERREQUEST
DESCRIPTOR.message_types_by_name['ConsensusBroadcastResponse'] = _CONSENSUSBROADCASTRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusBroadcastArbiterResponse'] = _CONSENSUSBROADCASTARBITERRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusBroadcastClusterResponse'] = _CONSENSUSBROADCASTCLUSTERRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusInitializeBlockRequest'] = _CONSENSUSINITIALIZEBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusInitializeBlockResponse'] = _CONSENSUSINITIALIZEBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusSummarizeBlockRequest'] = _CONSENSUSSUMMARIZEBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusSummarizeBlockResponse'] = _CONSENSUSSUMMARIZEBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusFinalizeBlockRequest'] = _CONSENSUSFINALIZEBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusFinalizeBlockResponse'] = _CONSENSUSFINALIZEBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusCancelBlockRequest'] = _CONSENSUSCANCELBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusCancelBlockResponse'] = _CONSENSUSCANCELBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusCheckBlocksRequest'] = _CONSENSUSCHECKBLOCKSREQUEST
DESCRIPTOR.message_types_by_name['ConsensusCheckBlocksResponse'] = _CONSENSUSCHECKBLOCKSRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusCommitBlockRequest'] = _CONSENSUSCOMMITBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusCommitBlockResponse'] = _CONSENSUSCOMMITBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusIgnoreBlockRequest'] = _CONSENSUSIGNOREBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusIgnoreBlockResponse'] = _CONSENSUSIGNOREBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusFailBlockRequest'] = _CONSENSUSFAILBLOCKREQUEST
DESCRIPTOR.message_types_by_name['ConsensusFailBlockResponse'] = _CONSENSUSFAILBLOCKRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusBlocksGetRequest'] = _CONSENSUSBLOCKSGETREQUEST
DESCRIPTOR.message_types_by_name['ConsensusBlocksGetResponse'] = _CONSENSUSBLOCKSGETRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusChainHeadGetRequest'] = _CONSENSUSCHAINHEADGETREQUEST
DESCRIPTOR.message_types_by_name['ConsensusChainHeadGetResponse'] = _CONSENSUSCHAINHEADGETRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusSettingsGetRequest'] = _CONSENSUSSETTINGSGETREQUEST
DESCRIPTOR.message_types_by_name['ConsensusSettingsGetResponse'] = _CONSENSUSSETTINGSGETRESPONSE
DESCRIPTOR.message_types_by_name['ConsensusStateGetRequest'] = _CONSENSUSSTATEGETREQUEST
DESCRIPTOR.message_types_by_name['ConsensusStateGetResponse'] = _CONSENSUSSTATEGETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConsensusPeerMessageHeader = _reflection.GeneratedProtocolMessageType('ConsensusPeerMessageHeader', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSPEERMESSAGEHEADER,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusPeerMessageHeader)
  ))
_sym_db.RegisterMessage(ConsensusPeerMessageHeader)

ConsensusPeerMessageNew = _reflection.GeneratedProtocolMessageType('ConsensusPeerMessageNew', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSPEERMESSAGENEW,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusPeerMessageNew)
  ))
_sym_db.RegisterMessage(ConsensusPeerMessageNew)

ConsensusPeerMessage = _reflection.GeneratedProtocolMessageType('ConsensusPeerMessage', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSPEERMESSAGE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusPeerMessage)
  ))
_sym_db.RegisterMessage(ConsensusPeerMessage)

ConsensusBlock = _reflection.GeneratedProtocolMessageType('ConsensusBlock', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBLOCK,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBlock)
  ))
_sym_db.RegisterMessage(ConsensusBlock)

ConsensusPeerInfo = _reflection.GeneratedProtocolMessageType('ConsensusPeerInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSPEERINFO,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusPeerInfo)
  ))
_sym_db.RegisterMessage(ConsensusPeerInfo)

ConsensusSettingsEntry = _reflection.GeneratedProtocolMessageType('ConsensusSettingsEntry', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSETTINGSENTRY,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSettingsEntry)
  ))
_sym_db.RegisterMessage(ConsensusSettingsEntry)

ConsensusStateEntry = _reflection.GeneratedProtocolMessageType('ConsensusStateEntry', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSTATEENTRY,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusStateEntry)
  ))
_sym_db.RegisterMessage(ConsensusStateEntry)

ConsensusRegisterRequest = _reflection.GeneratedProtocolMessageType('ConsensusRegisterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSREGISTERREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusRegisterRequest)
  ))
_sym_db.RegisterMessage(ConsensusRegisterRequest)

ConsensusRegisterResponse = _reflection.GeneratedProtocolMessageType('ConsensusRegisterResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSREGISTERRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusRegisterResponse)
  ))
_sym_db.RegisterMessage(ConsensusRegisterResponse)

ConsensusNotifyPeerConnected = _reflection.GeneratedProtocolMessageType('ConsensusNotifyPeerConnected', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYPEERCONNECTED,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyPeerConnected)
  ))
_sym_db.RegisterMessage(ConsensusNotifyPeerConnected)

ConsensusNotifyPeerDisconnected = _reflection.GeneratedProtocolMessageType('ConsensusNotifyPeerDisconnected', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYPEERDISCONNECTED,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyPeerDisconnected)
  ))
_sym_db.RegisterMessage(ConsensusNotifyPeerDisconnected)

ConsensusNotifyPeerMessage = _reflection.GeneratedProtocolMessageType('ConsensusNotifyPeerMessage', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYPEERMESSAGE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyPeerMessage)
  ))
_sym_db.RegisterMessage(ConsensusNotifyPeerMessage)

ConsensusNotifyPeerMessageNew = _reflection.GeneratedProtocolMessageType('ConsensusNotifyPeerMessageNew', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYPEERMESSAGENEW,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyPeerMessageNew)
  ))
_sym_db.RegisterMessage(ConsensusNotifyPeerMessageNew)

ConsensusNotifyBlockNew = _reflection.GeneratedProtocolMessageType('ConsensusNotifyBlockNew', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYBLOCKNEW,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyBlockNew)
  ))
_sym_db.RegisterMessage(ConsensusNotifyBlockNew)

ConsensusNotifyBlockValid = _reflection.GeneratedProtocolMessageType('ConsensusNotifyBlockValid', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYBLOCKVALID,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyBlockValid)
  ))
_sym_db.RegisterMessage(ConsensusNotifyBlockValid)

ConsensusNotifyBlockInvalid = _reflection.GeneratedProtocolMessageType('ConsensusNotifyBlockInvalid', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYBLOCKINVALID,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyBlockInvalid)
  ))
_sym_db.RegisterMessage(ConsensusNotifyBlockInvalid)

ConsensusNotifyBlockCommit = _reflection.GeneratedProtocolMessageType('ConsensusNotifyBlockCommit', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYBLOCKCOMMIT,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyBlockCommit)
  ))
_sym_db.RegisterMessage(ConsensusNotifyBlockCommit)

ConsensusNotifyAck = _reflection.GeneratedProtocolMessageType('ConsensusNotifyAck', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSNOTIFYACK,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusNotifyAck)
  ))
_sym_db.RegisterMessage(ConsensusNotifyAck)

ConsensusSendToRequest = _reflection.GeneratedProtocolMessageType('ConsensusSendToRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSENDTOREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSendToRequest)
  ))
_sym_db.RegisterMessage(ConsensusSendToRequest)

ConsensusSendToResponse = _reflection.GeneratedProtocolMessageType('ConsensusSendToResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSENDTORESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSendToResponse)
  ))
_sym_db.RegisterMessage(ConsensusSendToResponse)

ConsensusBroadcastRequest = _reflection.GeneratedProtocolMessageType('ConsensusBroadcastRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBROADCASTREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBroadcastRequest)
  ))
_sym_db.RegisterMessage(ConsensusBroadcastRequest)

ConsensusBroadcastClusterRequest = _reflection.GeneratedProtocolMessageType('ConsensusBroadcastClusterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBROADCASTCLUSTERREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBroadcastClusterRequest)
  ))
_sym_db.RegisterMessage(ConsensusBroadcastClusterRequest)

ConsensusBroadcastArbiterRequest = _reflection.GeneratedProtocolMessageType('ConsensusBroadcastArbiterRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBROADCASTARBITERREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBroadcastArbiterRequest)
  ))
_sym_db.RegisterMessage(ConsensusBroadcastArbiterRequest)

ConsensusBroadcastResponse = _reflection.GeneratedProtocolMessageType('ConsensusBroadcastResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBROADCASTRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBroadcastResponse)
  ))
_sym_db.RegisterMessage(ConsensusBroadcastResponse)

ConsensusBroadcastArbiterResponse = _reflection.GeneratedProtocolMessageType('ConsensusBroadcastArbiterResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBROADCASTARBITERRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBroadcastArbiterResponse)
  ))
_sym_db.RegisterMessage(ConsensusBroadcastArbiterResponse)

ConsensusBroadcastClusterResponse = _reflection.GeneratedProtocolMessageType('ConsensusBroadcastClusterResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBROADCASTCLUSTERRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBroadcastClusterResponse)
  ))
_sym_db.RegisterMessage(ConsensusBroadcastClusterResponse)

ConsensusInitializeBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusInitializeBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSINITIALIZEBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusInitializeBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusInitializeBlockRequest)

ConsensusInitializeBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusInitializeBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSINITIALIZEBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusInitializeBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusInitializeBlockResponse)

ConsensusSummarizeBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusSummarizeBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSUMMARIZEBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSummarizeBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusSummarizeBlockRequest)

ConsensusSummarizeBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusSummarizeBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSUMMARIZEBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSummarizeBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusSummarizeBlockResponse)

ConsensusFinalizeBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusFinalizeBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSFINALIZEBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusFinalizeBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusFinalizeBlockRequest)

ConsensusFinalizeBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusFinalizeBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSFINALIZEBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusFinalizeBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusFinalizeBlockResponse)

ConsensusCancelBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusCancelBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCANCELBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusCancelBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusCancelBlockRequest)

ConsensusCancelBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusCancelBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCANCELBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusCancelBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusCancelBlockResponse)

ConsensusCheckBlocksRequest = _reflection.GeneratedProtocolMessageType('ConsensusCheckBlocksRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCHECKBLOCKSREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusCheckBlocksRequest)
  ))
_sym_db.RegisterMessage(ConsensusCheckBlocksRequest)

ConsensusCheckBlocksResponse = _reflection.GeneratedProtocolMessageType('ConsensusCheckBlocksResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCHECKBLOCKSRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusCheckBlocksResponse)
  ))
_sym_db.RegisterMessage(ConsensusCheckBlocksResponse)

ConsensusCommitBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusCommitBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCOMMITBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusCommitBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusCommitBlockRequest)

ConsensusCommitBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusCommitBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCOMMITBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusCommitBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusCommitBlockResponse)

ConsensusIgnoreBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusIgnoreBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSIGNOREBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusIgnoreBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusIgnoreBlockRequest)

ConsensusIgnoreBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusIgnoreBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSIGNOREBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusIgnoreBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusIgnoreBlockResponse)

ConsensusFailBlockRequest = _reflection.GeneratedProtocolMessageType('ConsensusFailBlockRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSFAILBLOCKREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusFailBlockRequest)
  ))
_sym_db.RegisterMessage(ConsensusFailBlockRequest)

ConsensusFailBlockResponse = _reflection.GeneratedProtocolMessageType('ConsensusFailBlockResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSFAILBLOCKRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusFailBlockResponse)
  ))
_sym_db.RegisterMessage(ConsensusFailBlockResponse)

ConsensusBlocksGetRequest = _reflection.GeneratedProtocolMessageType('ConsensusBlocksGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBLOCKSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBlocksGetRequest)
  ))
_sym_db.RegisterMessage(ConsensusBlocksGetRequest)

ConsensusBlocksGetResponse = _reflection.GeneratedProtocolMessageType('ConsensusBlocksGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSBLOCKSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusBlocksGetResponse)
  ))
_sym_db.RegisterMessage(ConsensusBlocksGetResponse)

ConsensusChainHeadGetRequest = _reflection.GeneratedProtocolMessageType('ConsensusChainHeadGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCHAINHEADGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusChainHeadGetRequest)
  ))
_sym_db.RegisterMessage(ConsensusChainHeadGetRequest)

ConsensusChainHeadGetResponse = _reflection.GeneratedProtocolMessageType('ConsensusChainHeadGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSCHAINHEADGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusChainHeadGetResponse)
  ))
_sym_db.RegisterMessage(ConsensusChainHeadGetResponse)

ConsensusSettingsGetRequest = _reflection.GeneratedProtocolMessageType('ConsensusSettingsGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSETTINGSGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSettingsGetRequest)
  ))
_sym_db.RegisterMessage(ConsensusSettingsGetRequest)

ConsensusSettingsGetResponse = _reflection.GeneratedProtocolMessageType('ConsensusSettingsGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSETTINGSGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusSettingsGetResponse)
  ))
_sym_db.RegisterMessage(ConsensusSettingsGetResponse)

ConsensusStateGetRequest = _reflection.GeneratedProtocolMessageType('ConsensusStateGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSTATEGETREQUEST,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusStateGetRequest)
  ))
_sym_db.RegisterMessage(ConsensusStateGetRequest)

ConsensusStateGetResponse = _reflection.GeneratedProtocolMessageType('ConsensusStateGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSSTATEGETRESPONSE,
  __module__ = 'dgt_sdk.protobuf.consensus_pb2'
  # @@protoc_insertion_point(class_scope:ConsensusStateGetResponse)
  ))
_sym_db.RegisterMessage(ConsensusStateGetResponse)


# @@protoc_insertion_point(module_scope)
